/* Transient calcium channel implemented using tab channels */
/* Activation - ss and tau */

function TChanAct(voltage)

    float voltage
    float vh = -30.0
    float vc = -10.0

  float act = {1 / {1 + {exp {{{voltage}  - {vh}} / {vc}}}}}

    return act
end


function TChanTauAct(voltage) 

    float voltage

    return 5
end

/* Inactivation - ss and tau */
function TChanInact(voltage)

    float voltage
    float vh = -49
    float vc = 6
    return {1 / {1 + {exp {-{{voltage} - {vh}} / {vc}}}}}

end

function TChanTauInact(voltage) 

    float voltage

    return 75

end

function make_TCa_channel (path, gmax)

    str path  
    float gmax

    float Erev = 60  /* reversal potential of calcium */
    float xmin = -100   /* minimum voltage we will see in the simulation */
    float xmax = 60   /* maximum voltage we will see in the simulation */
    float step = 5  /* use a 5mV step size */
    int xdivs = 30      /* the number of divisions between -0.1 and 0.05 */
    int c = 0

    create tabchannel {path}

    /* make the table for the activation with a range of -100mV - +50mV
     * with an entry for ever 5mV
     */
    call {path} TABCREATE X {xdivs} {xmin} {xmax}
    call {path} TABCREATE Y {xdivs} {xmin} {xmax}

    /* set the tau and m_inf for the activation and inactivation */
    for(c = 0; c <= {xdivs}; c = c + 1)
        setfield {path} X_A->table[{c}] {TChanTauAct {{c * {step}} + xmin}}
        setfield {path} X_B->table[{c}] {TChanAct {{c * {step}} + xmin}}
        setfield {path} Y_A->table[{c}] {TChanTauInact {{c * {step}} + xmin}}
        setfield {path} Y_B->table[{c}] {TChanInact {{c * {step}} + xmin}}
    end

    /* this is fudged from the genesis book */
    setfield {path} Ek {Erev} Gbar {gmax} Xpower 2 Ypower 1
    
    /* fill the tables with the values of A and B
     * calculated from tau and m_inf
     */

/* for testing */
//for(c = 0; c < 30; c = c + 1)  
//        showfield A_channel X_A->table[{c}] 
//        showfield {path} X_B->table[{c}] 
//        showfield {path} Y_A->table[{c}] 
//        showfield {path} Y_B->table[{c}] 
//    end

    tweaktau {path} X
    tweaktau {path} Y


    call {path} TABFILL X 3000 0
    call {path} TABFILL Y 3000 0
end









