//genesis2.3
//cal6.g
/*This tutorial uses only genesis objects
 *Ca_concen for the calcium concentration - single time constant decay
 * tab channels for current - which uses modeler convention - inward currents are positive
 * changing tau from 10 to 20 significantly increases peak calcium concentration
 * increasing gmax increases concentration and current simultaneously
 * increasing dendritic length has very complex effects:
      1. increases volume for accumulating calcium (without increase current)
      2. larger compartment for integrating current - less depolarization means lower current
 * better to have gmax proportional to surface area
*/

//dimensions of compartments defined near the top for ease of changing
float somarad=2e-4
float somalen=1e-4
float dendrad=1e-4
float dendlen=10e-4
float RA = 100e-6  /* Mohm-cm, could be 200e-6 */
float RM = 1e-2    /* Megaohms - cm^2; 5e-2 from Spruston et al */
float CM = 1e3     /* nanoFarads/cm^2; 1e3 from Spruston et al. */
float PI=3.14159
float PCaT=0.01
float gmax=2e-4   //nA

//function to create compartment
include comp.g
//function to create calcium channel
include cachan.g

//create electrical cell compartment
make_comp soma {somalen} {somarad}
make_comp dendrite {dendlen} {dendrad}
addmsg dendrite soma RAXIAL Ra previous_state
addmsg soma dendrite AXIAL  previous_state

/***** calcium concentration pools ****/
create neutral caext
setfield caext z 10000          //umol

create Ca_concen dendrite/Ca_conc
float vol= PI*dendrad*dendrad*dendlen/1000       //1000 cm3/L
float Faraday=96485             // uC/umol - current in uA
float factor = {0.5*1e-6/Faraday/vol}    // 0.001 sec/msec, 0.001 uA/nA
echo "B=" {factor}

setfield dendrite/Ca_conc \
            tau     20   \      // msec
            B       {factor} \      // 1/Faraday/vol/NA
            Ca_base 0.05
 
//add calcium channels
make_TCa_channel "dendrite/TCachan" {gmax}

//messages between channels and pools/compartments
addmsg dendrite dendrite/TCachan VOLTAGE Vm
addmsg dendrite/TCachan dendrite CHANNEL G Ek
addmsg dendrite/TCachan dendrite/Ca_conc I_Ca Ik


//setup graphs to display results
include cal6graph.g

//again, use a larger dt for output
setclock 0 0.001
setclock 1 0.1

reset
step 40000
setfield soma inject 0.01
step 30000
setfield soma inject 0
step 30000
step 400000
setfield /graph1/# xmax 1000
step 500000
setfield /graph1/# xmax 2000
step 1000000

